/*
 * $Header: /plaid/homes/zeus/Blind-2.47/protos/RCS/version.h,v 2.47 1998/04/15 21:36:07 zeus Exp zeus $
 *
 * $Log: version.h,v $
 * Revision 2.47  1998/04/15 21:36:07  zeus
 * *** empty log message ***
 *
 * Revision 2.45  1997/01/01  00:15:27  zeus
 * *** empty log message ***
 *
 * Revision 2.44  1995/12/31  19:45:18  zeus
 * *** empty log message ***
 *
 * Revision 2.43  1995/03/20  01:43:09  zeus
 * *** empty log message ***
 *
 * Revision 2.40  1994/03/09  20:22:55  bampton
 * *** empty log message ***
 *
 * Revision 2.37  1993/09/07  20:47:59  bampton
 * *** empty log message ***
 *
 *
 */

/* Prototypes for rcsid functions */
void blind_rcsid (void);
void new_galaxy_rcsid (void);
void addplayer_rcsid (void);
void battle_rcsid (void);
void enterturn_rcsid (void);
void i_o_rcsid (void);
void misc_rcsid (void);
void new_game_rcsid (void);
void report_rcsid (void);
void turn_rcsid (void);
void savegame_rcsid(void);
void loadgame_rcsid(void);
void cmds_rcsid(void);
void a_cmd_rcsid(void);
void b_cmd_rcsid(void);
void c_cmd_rcsid(void);
void d_cmd_rcsid(void);
void e_cmd_rcsid(void);
void f_cmd_rcsid(void);
void g_cmd_rcsid(void);
void h_cmd_rcsid(void);
void i_cmd_rcsid(void);
void j_cmd_rcsid(void);
void k_cmd_rcsid(void);
void l_cmd_rcsid(void);
void m_cmd_rcsid(void);
void n_cmd_rcsid(void);
void o_cmd_rcsid(void);
void p_cmd_rcsid(void);
void r_cmd_rcsid(void);
void s_cmd_rcsid(void);
void t_cmd_rcsid(void);
void u_cmd_rcsid(void);
void v_cmd_rcsid(void);
void w_cmd_rcsid(void);
void x_cmd_rcsid(void);
void y_cmd_rcsid(void);
void z_cmd_rcsid(void);
void report_status_rcsid(void);
void report_ships_rcsid(void);
void report_planets_rcsid(void);
void report_map_rcsid(void);
void report_gm_rcsid(void);
void report_main_rcsid(void);
void report_battle_rcsid(void);
